import java.util.*;

/** Person Identity that provide big constructor to
 * construct complex state. 
 
   This source code is from the book 
     "Flexible, Reliable Software:
       Using Patterns and Agile Development"
     published by CRC Press.
   Author: 
     Henrik B Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/

public class PersonIdentityVanilla {
  
  private String ssn;
  private String title;
  private String[] givenNames;
  private String familyName;
  private Gender gender;
  private Date birthTime;

  private String[] phoneNumbers;

  public PersonIdentityVanilla(String familyName, String title,
      String[] givenNames, Gender gender, String personID, String[] phoneNumbers, 
      int birthYear, int birthMonth, int birthDayInMonth) {
    this.familyName = familyName;
    this.title = title;
    this.gender = gender;
    this.ssn = personID;
    this.givenNames = givenNames;
    this.phoneNumbers = phoneNumbers;
    if (birthYear != 0) {
      Calendar utcCalendar = Calendar.getInstance(TimeZone.getTimeZone("UTC"));
      utcCalendar.set(birthYear, birthMonth, birthDayInMonth, 0, 0, 0);
      birthTime = utcCalendar.getTime();
    }
    // Constraint based setting of title
    if (title == null) {
      if (gender == Gender.Male) {
        this.title = "Mr.";
      } else {
        this.title = "Miss";
      }
    }
  }
  
  /** Get the social security number.
   * @return The social security number.
   */
  public String getSSN() {
    return ssn;
  }

  /** Get person title.
   * @return title string.
   */
  public String getTitle() {
    return title;
  }

  /** Get list of given names.
   * @return list of given names.
   */
  public String[] getGivenNames() {
    return givenNames;
  }

  /** Get family name.
   * @return family name string.
   */
  public String getFamilyName() {
    return familyName;
  }

  /** Get person gender.
   * @return gender type.
   */
  public Gender getGender() {
    return gender;
  }

  /** Get person birth time.
   * @return birth time date.
   */
  public Date getBirthTime() {
    return birthTime;
  }

  /** Get person phone numbers.
   * @return phone number array.
   */
  public String[] getPhoneNumbers() {
    if (phoneNumbers == null) {
      phoneNumbers = new String[]{}; // Empty array
    }
    return phoneNumbers;
  }

  public String toString() {
    String result = "PersonIdentity:\n";

    result += " Title         : " + title + "\n";
    result += " Family name   : " + getFamilyName() + "\n";
    result += " Given name(s) : ";
    for (String firstname: getGivenNames()) {
      result += firstname + " / ";
    }
    result += "\n";

    result += " Gender        : " + getGender() + "\n";
    
    result += " SSN/ID        : " + getSSN() + "\n";
    
    result += " Birth         : " + getBirthTime() + "\n";
    
    if (phoneNumbers != null) {
      result += " Phone         : [";
      for (String tc : getPhoneNumbers()) {
        result += tc + ",";
      }
      result += "]\n";
    }
    
    result += "---";

    return result;
  }


}
