package marker;

import minidraw.standard.*;
import minidraw.framework.*;

import rect.*;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/** Demonstrate MiniDraw Observer ability.
 * Demonstrates:
 * A) Register to listen to FigureChangeEvents
 * B) Make a figure react upon events
 * C) Use of Decorator to implement this behavior
 *
 * Move the AU seal using the mouse, and uses the
 * FigureChange Observer pattern mechanisms of MiniDraw
 * to make the two arrows always point to the logo.

   This source code is from the book 
     "Flexible, Reliable Software:
       Using Patterns and Agile Development"
     published by CRC Press.
   Author: 
     Henrik B Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class Markers {
  public static void main(String[] args) {
    Factory f = new EmptyCanvasFactory();
    DrawingEditor editor = 
      new MiniDrawApplication( "Markers - move the white seal", f );

    editor.open();
    Figure logo = new ImageFigure( "au-seal-small", new Point(200, 200));

    Figure rightArrow = 
      new MarkerFigureDecorator( new ImageFigure( "arrow-right", 
                                                  new Point(0, 200)),
                                 logo,
                                 false );
    Figure downArrow = 
      new MarkerFigureDecorator( new ImageFigure( "arrow-down", 
                                                  new Point(200, 0)),
                                 logo,
                                 true );

    editor.setTool( new SelectionTool(editor) );

    editor.drawing().add(rightArrow);
    editor.drawing().add(downArrow);
    editor.drawing().add(logo);
  }
}

class EmptyCanvasFactory implements Factory {

  public DrawingView createDrawingView( DrawingEditor editor ) {
    return new StandardDrawingView(editor);
  }

  public Drawing createDrawing( DrawingEditor editor ) {
    return new StandardDrawing();
  }

  public JTextField createStatusField( DrawingEditor editor ) {
    return null;
  }
}
