package rect;

import minidraw.standard.*;
import minidraw.framework.*;

import java.awt.*;

/** A MiniDraw rectangle figure.

   This source code is from the book 
     "Flexible, Reliable Software:
       Using Patterns and Agile Development"
     published by CRC Press.
   Author: 
     Henrik B Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */
public class RectangleFigure extends AbstractFigure {

  private Rectangle     fDisplayBox;
  private Color         color;

  /** Create a green rectangle figure.
      @param origin the coordinate of the origin
      @param corner the coordinate of the corner */
  public RectangleFigure(Point origin, Point corner) {
    basicResize(origin,corner);
    color = Color.GREEN;
  }
  /** Create a rectangle figure of a given color.
      @param origin the coordinate of the origin
      @param corner the coordinate of the corner 
      @param color the color of the rectangle */
  public RectangleFigure(Point origin, Point corner, Color color) {
    basicResize(origin,corner);
    this.color = color;
  }

  /** Create an 'empty' rectangle figure.
      @param origin the coordinate of the origin */
  public RectangleFigure(Point origin) {
    this(origin, origin);
  }
 
  protected void basicResize(Point origin, Point corner) {
    fDisplayBox = new Rectangle(origin);
    fDisplayBox.add(corner);
  }

  public Rectangle displayBox() {
    return new Rectangle(
                         fDisplayBox.x,
                         fDisplayBox.y,
                         fDisplayBox.width,
                         fDisplayBox.height);
  }

  protected void basicMoveBy(int x, int y) {
    fDisplayBox.translate(x,y);
  }

  protected void resize(Point origin, Point corner) {
    willChange();
    basicResize(origin,corner);
    changed();
  }
  
  public void draw(Graphics g) {
    Rectangle r = displayBox();
    g.setColor(color);
    g.fillRect(r.x, r.y, r.width, r.height);
    g.setColor(Color.BLACK);
    g.drawRect(r.x, r.y, r.width-1, r.height-1);
  }
}
