package paystation.domain;

import org.junit.*;
import static org.junit.Assert.*;

/** Testcases for the BetaTown pay station with progressive rate policy.
 
   This source code is from the book 
     "Flexible, Reliable Software:
       Using Patterns and Agile Development"
     published by CRC Press.
   Author: 
     Henrik B Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class TestProgressiveRate {
  PayStation ps;
  /** Fixture for pay station testing. */
  @Before
  public void setUp() {
    ps = new PayStationImpl( new ProgressiveRateStrategy() );
  }

  /** Test a single hour parking */
  @Test public void shouldDisplay60MinFor150cent() 
          throws IllegalCoinException { 
    // First hour: $1.5
    addOneDollar();
    addHalfDollar();

    assertEquals( 60 /*minutes*/, ps.readDisplay() ); 
  }

  private void addHalfDollar() throws IllegalCoinException  {
    ps.addPayment( 25 ); ps.addPayment( 25 ); 
  }
  private void addOneDollar() throws IllegalCoinException {
    addHalfDollar(); addHalfDollar();
  }
} 
