/** Skeleton code for a ContactBook to demonstrate the difference
    between static and dynamic view of a software system.
 
   This source code is from the book 
     "Flexible, Reliable Software:
       Using Patterns and Agile Development"
     published by CRC Press.
   Author: 
     Henrik B Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
import java.util.*;

public class ContactBook {
  /** the contents of this contact book. */
  private List<Contact> contents = new ArrayList<Contact>();
  /** add a contact to the contact book. 
   * @param c the contact to add
  */
  public void add(Contact c) { contents.add(c); }
  /** print the contents of this book. */
  public void print() {
    for( Contact c : contents ) {
      System.out.println( c );
    }
  }

  /** demonstration of contact book usage. */
  public static void main(String[] args) {
    ContactBook book = new ContactBook();
    book.add( new Contact("James Smith", 
                          "New York", "212-456-7890" ) );
    book.add( new Contact("Mary Johnson", 
                          "Lake Placid", "518-567-8901" ) );
    book.add( new Contact("Linda Willams", 
                          "Rochester", "585-678-9012" ) );
    book.print();
  }
}

/** Simple storage class for contact data.

   This source code is from the book 
     "Flexible, Reliable Software:
       Using Patterns and Agile Development"
     published by CRC Press.
   Author: 
     Henrik B Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
class Contact {
  String name;
  String address;
  String phone;

  /** construct a contact with the provided information.
   * @param name the contact's name
   * @param address the contact's address
   * @param phone the contact's telephone number
   */
  public Contact(String name, String address, String phone) {
    this.name = name; this.address = address; this.phone = phone;
  }
  /** return string representation of this contact.
   * @return string representation of this contact
   */
  public String toString() {
    return name+" ("+address+"): "+phone;
  }
}
