package breakthrough.domain;

import org.junit.*;
import static org.junit.Assert.*;
import static org.hamcrest.CoreMatchers.*;

/** An incomplete test suite for the surrogate implementation
 * of Breakthrough.
 
   This source code is from the book 
     "Flexible, Reliable Software:
       Using Patterns and Agile Development"
     published by CRC Press.
   Author: 
     Henrik B Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/
public class TestBreakthroughSurrogate {
  private Breakthrough game;
  /** Fixture */
  @Before
  public void setUp() {
    game = new BreakthroughSurrogate();
  }
  
  @Test
  public void shouldHaveInitialBlackPawns(){
    // "Boundary tests" of black's initial positions
    assertThat(game.getPieceAt(new Position(0, 0)),
            is(Color.BLACK));
    assertThat(game.getPieceAt(new Position(0, 7)),
            is(Color.BLACK));
    assertThat(game.getPieceAt(new Position(1, 0)),
            is(Color.BLACK));
    assertThat(game.getPieceAt(new Position(1, 7)),
            is(Color.BLACK));

    assertThat(game.getPieceAt(new Position(2, 3)),
            is(not(Color.BLACK)));
    assertThat(game.getPieceAt(new Position(7, 0)),
            is(not(Color.BLACK)));
  }

  @Test
  public void shouldHaveInitialWhitePawns(){
    // "Boundary tests" of white's initial positions
    assertThat(game.getPieceAt(new Position(6, 0)),
            is(Color.WHITE));
    assertThat(game.getPieceAt(new Position(6, 7)),
            is(Color.WHITE));
    assertThat(game.getPieceAt(new Position(7, 0)),
            is(Color.WHITE));
    assertThat(game.getPieceAt(new Position(7, 7)),
            is(Color.WHITE));

    assertThat(game.getPieceAt(new Position(2, 3)),
            is(not(Color.WHITE)));
    assertThat(game.getPieceAt(new Position(1, 0)),
            is(not(Color.WHITE)));
  }

  @Test
  public void shouldHandleValidAndInvalidMoves() {
    // Spot testing of valid and invalid moves
    assertThat(game.getPlayerInTurn(), is(Color.WHITE));

    Position f = new Position(6,5),
    t = new Position(5,5);
    assertThat(game.move( new Move(f, t)),
            is(true));
    // Validate that move was made
    assertThat(game.getPieceAt(f), is(Color.NONE));
    assertThat(game.getPieceAt(t), is(Color.WHITE));

    // second move is illegal as it is black's turn
    assertThat(game.getPlayerInTurn(), is(Color.BLACK));
    f = new Position(5,5); t = new Position(4,5);
    assertThat(game.move( new Move(f,t)),
            is(false));

    // do not allow moving non existing pawns
    assertThat(game.move(new Move(new Position(2,2), new Position(3,3))),
            is(false));

    // black can make move
    assertThat(game.move(new Move(new Position(1,1), new Position(2,2))),
            is(true));
    // Validate that move was made
    assertThat(game.getPieceAt(new Position(1,1)), is(Color.NONE));
    assertThat(game.getPieceAt(new Position(2,2)), is(Color.BLACK));
  }
}
