/** This class contains the set of moves that
    Gerry computes for black player. The
    relevant methods are getFrom(i) and getTo(i)
    that represents a move from one location to
    another. i represent the move number,
    starting from 0. Thus i may be in range 1..4
    depending on the number of moves possible
    for black. Method 'noOfMoves' indicate
    the number of moves possible - note in
    special situations on backgammon it may
    be 0 - if checkers in the bar and nowhere
    to move to.
   This source code is from the book 
     "Flexible, Reliable Software:
       Using Patterns and Agile Development"
     published by CRC Press.
   Author: 
     Henrik B Christensen 
     Department of Computer Science
     Aarhus University
   
   Please visit http://www.baerbak.com/ for further information.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
       http://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

 */
public class Move {
  int           index;
  int []        leg;
  boolean       solitude;

  public Move() {
    index = 0;
    leg = new int[8];
    solitude = false;
  }

  private Move( int theindex, 
                int [] theleg, boolean thesolitude ) {
    index = theindex;
    leg = new int[8];
    solitude = thesolitude;
    System.arraycopy(theleg, 0, leg, 0, 8 );
  }

  /** mark these moves as found as solitude moves */
  public void markAsSolitude() { solitude = true; }

  public void add(int from, int to) {
    leg[index++] = from;
    leg[index++] = to;
  }
  
  public int noOfMoves() {
    return index / 2;
  }
  
  public int getFrom(int at) {
    return leg[at*2];
  }
  public int getTo(int at) {
    return leg[at*2+1];
  }

  /** return true in case the moves are a 'solitude'
      move i.e. a move that could only be accomplished by using
      only one of the dice */
  public boolean isSolitude() {
    return solitude;
  }
  
  public Move getClone() {
    return new Move(index,leg,solitude);
  }
  
  public String toString() {
    String val = "Move: "+ (isSolitude() == true ? "solitude" : "" );
    for ( int i = 0; i < noOfMoves(); i++ ) {
      val += "("+getFrom(i)+"-"+getTo(i)+") ";
    }
    return val;
  }
}
